import { Resend } from "resend";
import { AbstractNotificationService, CartService, ClaimService, FulfillmentProviderService, GiftCardService, LineItem, LineItemService, Order, OrderService, ProductVariantService, ReturnService, StoreService, SwapService, TotalsService } from "@medusajs/medusa";
import { Attachment, EventData, PricedLineItem, PricedReturnItem, ResendOptions } from "../types";
import { FulfillmentService } from "@medusajs/medusa/dist/services";
declare class ResendService extends AbstractNotificationService {
    static identifier: string;
    options_: any;
    protected templatePath_: string;
    protected fulfillmentProviderService_: FulfillmentProviderService;
    protected storeService_: StoreService;
    protected lineItemService_: LineItemService;
    protected orderService_: OrderService;
    protected cartService_: CartService;
    protected claimService_: ClaimService;
    protected returnService_: ReturnService;
    protected swapService_: SwapService;
    protected fulfillmentService_: FulfillmentService;
    protected totalsService_: TotalsService;
    protected productVariantService_: ProductVariantService;
    protected giftCardService_: GiftCardService;
    protected transporter_: Resend;
    /**
     * @param {Object} options - options defined in `medusa-config.js`
     *    e.g.
     *    {
     *      api_key: process.env.RESEND_API_KEY,
     *      from: process.env.RESEND_FROM,
     *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
     *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
     *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
     *      template_path: process.env.RESEND_TEMPLATE_PATH,
     *      order_placed_template: 'order_placed',
     *		 order_shipped_template: 'order_shipped',
     *		 customer_password_reset_template: 'customer_password_reset',
     *		 gift_card_created_template: 'gift_card_created',
     *		 order_canceled_template: 'order_canceled',
     *		 order_refund_created_template: 'order_refund_created',
     *		 order_return_requested_template: 'order_return_requested',
     *		 order_items_returned_template: 'order_items_returned',
     *		 swap_created_template: 'swap_created',
     *		 swap_shipment_created_template: 'swap_shipment_created',
     *		 swap_received_template: 'swap_received',
     *		 claim_shipment_created_template: 'claim_shipment_created',
     *		 user_password_reset_template: 'user_password_reset',
     *		 medusa_restock_template: 'medusa_restock',
     *    }
     */
    constructor(container: any, options: any);
    sendNotification(event: string, eventData: EventData, attachmentGenerator?: any): Promise<{
        to: string;
        status: string;
        data: Record<string, unknown>;
    }>;
    resendNotification(notification: any, config: any, attachmentGenerator: any): Promise<{
        to: string;
        status: string;
        data: Record<string, unknown>;
    }>;
    /**
     * Sends an email using Resend.
     * @param {string} template_id - id of template to use
     * @param {string} from - sender of email
     * @param {string} to - receiver of email
     * @param {Object} data - data to send in mail (match with template)
     * @return {Promise} result of the send operation
     */
    sendEmail(templateId: any, from: any, to: any, data: any): Promise<false | {
        message: string;
        results: {
            sendOptions: ResendOptions;
        };
        to?: undefined;
        status?: undefined;
        data?: undefined;
    } | {
        to: string | string[];
        status: any;
        data: ResendOptions;
        message?: undefined;
        results?: undefined;
    }>;
    compileSubjectTemplate(templateId: any, data: any): Promise<string | null>;
    compileBodyTemplate(templateId: any, data: any): Promise<{
        html: string | null;
        text: string | null;
    }>;
    compileReactTemplate(templateId: any, data: any): Promise<any>;
    getLocalizedTemplateId(event: any, locale: any): any;
    getTemplateId(event: string, subject?: boolean): any;
    fetchAttachments(event: string, data: Record<any, any>, attachmentGenerator?: any): Promise<Attachment[]>;
    fetchData(event: string, eventData: EventData, attachmentGenerator: any): Promise<Record<any, any>>;
    orderShipmentCreatedData({ id, fulfillment_id }: EventData): Promise<{
        locale: {} | null;
        order: Order;
        date: string;
        email: string;
        fulfillment: import("@medusajs/medusa").Fulfillment;
        tracking_links: import("@medusajs/medusa").TrackingLink[];
        tracking_number: string;
    }>;
    orderCanceledData({ id }: EventData): Promise<{
        locale: {} | null;
        has_discounts: number;
        has_gift_cards: number;
        date: string;
        items: {
            thumbnail: string | null;
            price: string;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            quantity: number;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        discounts: {
            is_giftcard: boolean;
            code: string;
            descriptor: string;
        }[];
        subtotal: string;
        gift_card_total: string;
        tax_total: string;
        discount_total: string;
        shipping_total: string;
        total: string;
        object: "order";
        status: import("@medusajs/medusa").OrderStatus;
        fulfillment_status: import("@medusajs/medusa").FulfillmentStatus;
        payment_status: import("@medusajs/medusa").PaymentStatus;
        display_id: number;
        cart_id: string;
        cart: import("@medusajs/medusa").Cart;
        customer_id: string;
        customer: import("@medusajs/medusa").Customer;
        email: string;
        billing_address_id: string;
        billing_address: import("@medusajs/medusa").Address;
        shipping_address_id: string;
        shipping_address: import("@medusajs/medusa").Address;
        region_id: string;
        region: import("@medusajs/medusa").Region;
        currency_code: string;
        currency: import("@medusajs/medusa").Currency;
        tax_rate: number | null;
        gift_cards: import("@medusajs/medusa").GiftCard[];
        shipping_methods: import("@medusajs/medusa").ShippingMethod[];
        payments: import("@medusajs/medusa").Payment[];
        fulfillments: import("@medusajs/medusa").Fulfillment[];
        returns: import("@medusajs/medusa").Return[];
        claims: import("@medusajs/medusa").ClaimOrder[];
        refunds: import("@medusajs/medusa").Refund[];
        swaps: import("@medusajs/medusa").Swap[];
        draft_order_id: string;
        draft_order: import("@medusajs/medusa").DraftOrder;
        edits: import("@medusajs/medusa").OrderEdit[];
        gift_card_transactions: import("@medusajs/medusa").GiftCardTransaction[];
        canceled_at: Date;
        metadata: Record<string, unknown>;
        no_notification: boolean;
        idempotency_key: string;
        external_id: string | null;
        sales_channel_id: string | null;
        sales_channel: import("@medusajs/medusa").SalesChannel;
        sales_channels?: import("@medusajs/medusa").SalesChannel[] | undefined;
        shipping_tax_total: number | null;
        raw_discount_total: number;
        item_tax_total: number | null;
        refunded_total: number;
        paid_total: number;
        refundable_amount: number;
        gift_card_tax_total: number;
        returnable_items?: LineItem[] | undefined;
        id: string;
        created_at: Date;
        updated_at: Date;
    }>;
    orderPlacedData({ id }: EventData): Promise<{
        locale: {} | null;
        has_discounts: number;
        has_gift_cards: number;
        date: string;
        items: PricedLineItem[];
        discounts: {
            is_giftcard: boolean;
            code: string;
            descriptor: string;
        }[];
        subtotal_ex_tax: string;
        subtotal: string;
        gift_card_total: string;
        tax_total: string;
        discount_total: string;
        shipping_total: string;
        total: string;
        object: "order";
        status: import("@medusajs/medusa").OrderStatus;
        fulfillment_status: import("@medusajs/medusa").FulfillmentStatus;
        payment_status: import("@medusajs/medusa").PaymentStatus;
        display_id: number;
        cart_id: string;
        cart: import("@medusajs/medusa").Cart;
        customer_id: string;
        customer: import("@medusajs/medusa").Customer;
        email: string;
        billing_address_id: string;
        billing_address: import("@medusajs/medusa").Address;
        shipping_address_id: string;
        shipping_address: import("@medusajs/medusa").Address;
        region_id: string;
        region: import("@medusajs/medusa").Region;
        currency_code: string;
        currency: import("@medusajs/medusa").Currency;
        tax_rate: number | null;
        gift_cards: import("@medusajs/medusa").GiftCard[];
        shipping_methods: import("@medusajs/medusa").ShippingMethod[];
        payments: import("@medusajs/medusa").Payment[];
        fulfillments: import("@medusajs/medusa").Fulfillment[];
        returns: import("@medusajs/medusa").Return[];
        claims: import("@medusajs/medusa").ClaimOrder[];
        refunds: import("@medusajs/medusa").Refund[];
        swaps: import("@medusajs/medusa").Swap[];
        draft_order_id: string;
        draft_order: import("@medusajs/medusa").DraftOrder;
        edits: import("@medusajs/medusa").OrderEdit[];
        gift_card_transactions: import("@medusajs/medusa").GiftCardTransaction[];
        canceled_at: Date;
        metadata: Record<string, unknown>;
        no_notification: boolean;
        idempotency_key: string;
        external_id: string | null;
        sales_channel_id: string | null;
        sales_channel: import("@medusajs/medusa").SalesChannel;
        sales_channels?: import("@medusajs/medusa").SalesChannel[] | undefined;
        shipping_tax_total: number | null;
        raw_discount_total: number;
        item_tax_total: number | null;
        refunded_total: number;
        paid_total: number;
        refundable_amount: number;
        gift_card_tax_total: number;
        returnable_items?: LineItem[] | undefined;
        id: string;
        created_at: Date;
        updated_at: Date;
    }>;
    gcCreatedData({ id }: EventData): Promise<{
        locale: {} | null;
        email: unknown;
        display_value: string;
        message: unknown;
        code: string;
        value: number;
        balance: number;
        region_id: string;
        region: import("@medusajs/medusa").Region;
        order_id: string;
        order: Order;
        is_disabled: boolean;
        ends_at: Date;
        tax_rate: number | null;
        metadata: Record<string, unknown>;
        deleted_at: Date | null;
        id: string;
        created_at: Date;
        updated_at: Date;
    }>;
    returnRequestedData({ id, return_id }: EventData): Promise<{
        locale: {} | null;
        has_shipping: boolean;
        email: string;
        items: PricedReturnItem[];
        subtotal: string;
        shipping_total: string;
        refund_amount: string;
        return_request: {
            refund_amount: string;
            status: import("@medusajs/medusa").ReturnStatus;
            items: import("@medusajs/medusa").ReturnItem[];
            swap_id: string | null;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string | null;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            order_id: string | null;
            order: Order;
            shipping_method: import("@medusajs/medusa").ShippingMethod;
            location_id: string | null;
            shipping_data: Record<string, unknown>;
            received_at: Date;
            no_notification: boolean | null;
            metadata: Record<string, unknown> | null;
            idempotency_key: string | null;
            id: string;
            created_at: Date;
            updated_at: Date;
        };
        order: Order;
        date: string;
    }>;
    swapReceivedData({ id }: EventData): Promise<{
        locale: {} | null;
        swap: import("@medusajs/medusa").Swap;
        order: Order;
        return_request: import("@medusajs/medusa").Return;
        date: string;
        swap_link: string | undefined;
        email: string;
        items: {
            totals: {
                unit_price: number;
                quantity: number;
                subtotal: number;
                tax_total: number;
                total: number;
                original_total: number;
                original_tax_total: number;
                tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
                discount_total: number;
                raw_discount_total: number;
            };
            price: string;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            thumbnail: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            quantity: number;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        return_items: {
            totals: {
                unit_price: number;
                quantity: number;
                subtotal: number;
                tax_total: number;
                total: number;
                original_total: number;
                original_tax_total: number;
                tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
                discount_total: number;
                raw_discount_total: number;
            };
            price: string;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            thumbnail: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            quantity: number;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        return_total: string;
        tax_total: string;
        refund_amount: string;
        additional_total: string;
    }>;
    swapCreatedData({ id }: EventData): Promise<{
        locale: {} | null;
        swap: import("@medusajs/medusa").Swap;
        order: Order;
        return_request: import("@medusajs/medusa").Return;
        date: string;
        swap_link: string | undefined;
        email: string;
        items: {
            totals: {
                unit_price: number;
                quantity: number;
                subtotal: number;
                tax_total: number;
                total: number;
                original_total: number;
                original_tax_total: number;
                tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
                discount_total: number;
                raw_discount_total: number;
            };
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            price: string;
            discounted_price: string;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            thumbnail: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            quantity: number;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        return_items: {
            totals: {
                unit_price: number;
                quantity: number;
                subtotal: number;
                tax_total: number;
                total: number;
                original_total: number;
                original_tax_total: number;
                tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
                discount_total: number;
                raw_discount_total: number;
            };
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            price: string;
            discounted_price: string;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            thumbnail: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            quantity: number;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        return_total: string;
        refund_amount: string;
        additional_total: string;
    }>;
    itemsReturnedData(data: EventData): Promise<{
        locale: {} | null;
        has_shipping: boolean;
        email: string;
        items: PricedReturnItem[];
        subtotal: string;
        shipping_total: string;
        refund_amount: string;
        return_request: {
            refund_amount: string;
            status: import("@medusajs/medusa").ReturnStatus;
            items: import("@medusajs/medusa").ReturnItem[];
            swap_id: string | null;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string | null;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            order_id: string | null;
            order: Order;
            shipping_method: import("@medusajs/medusa").ShippingMethod;
            location_id: string | null;
            shipping_data: Record<string, unknown>;
            received_at: Date;
            no_notification: boolean | null;
            metadata: Record<string, unknown> | null;
            idempotency_key: string | null;
            id: string;
            created_at: Date;
            updated_at: Date;
        };
        order: Order;
        date: string;
    }>;
    swapShipmentCreatedData({ id, fulfillment_id }: EventData): Promise<{
        locale: {} | null;
        swap: import("@medusajs/medusa").Swap;
        order: Order;
        items: {
            thumbnail: string | null;
            price: string;
            discounted_price: string;
            quantity: number;
            cart_id: string;
            cart: import("@medusajs/medusa").Cart;
            order_id: string | null;
            order: Order;
            swap_id: string;
            swap: import("@medusajs/medusa").Swap;
            claim_order_id: string;
            claim_order: import("@medusajs/medusa").ClaimOrder;
            tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
            adjustments: import("@medusajs/medusa").LineItemAdjustment[];
            original_item_id?: string | null | undefined;
            order_edit_id?: string | null | undefined;
            order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
            title: string;
            description: string | null;
            is_return: boolean;
            is_giftcard: boolean;
            should_merge: boolean;
            allow_discounts: boolean;
            has_shipping: boolean | null;
            unit_price: number;
            variant_id: string | null;
            variant: import("@medusajs/medusa").ProductVariant;
            product_id: string | null;
            fulfilled_quantity: number | null;
            returned_quantity: number | null;
            shipped_quantity: number | null;
            metadata: Record<string, unknown>;
            includes_tax: boolean; /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            refundable?: number | null | undefined;
            subtotal?: number | null | undefined;
            tax_total?: number | null | undefined;
            total?: number | null | undefined;
            original_total?: number | null | undefined;
            original_tax_total?: number | null | undefined;
            discount_total?: number | null | undefined;
            raw_discount_total?: number | null | undefined;
            gift_card_total?: number | null | undefined;
            id: string;
            created_at: Date;
            updated_at: Date;
        }[];
        date: string;
        email: string;
        tax_amount: string;
        paid_total: string;
        return_total: string;
        refund_amount: string;
        additional_total: string;
        fulfillment: import("@medusajs/medusa").Fulfillment;
        tracking_links: import("@medusajs/medusa").TrackingLink[];
        tracking_number: string;
    }>;
    claimShipmentCreatedData({ id, fulfillment_id }: EventData): Promise<{
        locale: {} | null;
        email: string;
        claim: import("@medusajs/medusa").ClaimOrder;
        order: Order;
        fulfillment: import("@medusajs/medusa").Fulfillment;
        tracking_links: import("@medusajs/medusa").TrackingLink[];
        tracking_number: string;
    }>;
    restockNotificationData({ variant_id, emails }: EventData): Promise<{
        product: {
            thumbnail: any;
            title: string;
            subtitle: string | null;
            description: string | null;
            handle: string | null;
            is_giftcard: boolean;
            status: import("@medusajs/medusa").ProductStatus;
            images: import("@medusajs/medusa").Image[];
            options: import("@medusajs/medusa").ProductOption[];
            variants: import("@medusajs/medusa").ProductVariant[];
            categories: import("@medusajs/medusa").ProductCategory[];
            profile_id: string;
            /**
             * @param {Object} options - options defined in `medusa-config.js`
             *    e.g.
             *    {
             *      api_key: process.env.RESEND_API_KEY,
             *      from: process.env.RESEND_FROM,
             *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
             *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
             *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
             *      template_path: process.env.RESEND_TEMPLATE_PATH,
             *      order_placed_template: 'order_placed',
             *		 order_shipped_template: 'order_shipped',
             *		 customer_password_reset_template: 'customer_password_reset',
             *		 gift_card_created_template: 'gift_card_created',
             *		 order_canceled_template: 'order_canceled',
             *		 order_refund_created_template: 'order_refund_created',
             *		 order_return_requested_template: 'order_return_requested',
             *		 order_items_returned_template: 'order_items_returned',
             *		 swap_created_template: 'swap_created',
             *		 swap_shipment_created_template: 'swap_shipment_created',
             *		 swap_received_template: 'swap_received',
             *		 claim_shipment_created_template: 'claim_shipment_created',
             *		 user_password_reset_template: 'user_password_reset',
             *		 medusa_restock_template: 'medusa_restock',
             *    }
             */
            profile: import("@medusajs/medusa").ShippingProfile;
            profiles: import("@medusajs/medusa").ShippingProfile[];
            weight: number | null;
            length: number | null;
            height: number | null;
            width: number | null;
            hs_code: string | null;
            origin_country: string | null;
            mid_code: string | null;
            material: string | null;
            collection_id: string | null;
            collection: import("@medusajs/medusa").ProductCollection;
            type_id: string | null;
            type: import("@medusajs/medusa").ProductType;
            tags: import("@medusajs/medusa").ProductTag[];
            discountable: boolean;
            external_id: string | null;
            metadata: Record<string, unknown> | null;
            sales_channels: import("@medusajs/medusa").SalesChannel[];
            deleted_at: Date | null;
            id: string;
            created_at: Date;
            updated_at: Date;
        };
        variant: import("@medusajs/medusa").ProductVariant;
        variant_id: string;
        emails: string[] | undefined;
    }>;
    userPasswordResetData(data: EventData): EventData;
    customerPasswordResetData(data: EventData): EventData;
    orderRefundCreatedData({ id, refund_id }: EventData): Promise<{
        order: Order;
        refund: import("@medusajs/medusa").Refund | undefined;
        refund_amount: string;
        email: string;
    }>;
    processItems_(items: LineItem[], taxRate: number, currencyCode: string): {
        thumbnail: string | null;
        price: string;
        cart_id: string;
        cart: import("@medusajs/medusa").Cart;
        order_id: string | null;
        order: Order;
        swap_id: string;
        swap: import("@medusajs/medusa").Swap;
        claim_order_id: string;
        claim_order: import("@medusajs/medusa").ClaimOrder;
        tax_lines: import("@medusajs/medusa").LineItemTaxLine[];
        adjustments: import("@medusajs/medusa").LineItemAdjustment[];
        original_item_id?: string | null | undefined;
        order_edit_id?: string | null | undefined;
        order_edit?: import("@medusajs/medusa").OrderEdit | null | undefined;
        title: string;
        description: string | null;
        is_return: boolean;
        is_giftcard: boolean;
        should_merge: boolean;
        allow_discounts: boolean;
        has_shipping: boolean | null;
        unit_price: number;
        variant_id: string | null;
        variant: import("@medusajs/medusa").ProductVariant;
        product_id: string | null;
        quantity: number;
        fulfilled_quantity: number | null;
        returned_quantity: number | null;
        shipped_quantity: number | null;
        metadata: Record<string, unknown>;
        includes_tax: boolean; /**
         * @param {Object} options - options defined in `medusa-config.js`
         *    e.g.
         *    {
         *      api_key: process.env.RESEND_API_KEY,
         *      from: process.env.RESEND_FROM,
         *      enable_endpoint: process.env.RESEND_ENABLE_ENDPOINT,
         *		 subject_template_type: process.env.RESEND_SUBJECT_TEMPLATE_TYPE,
         *		 body_template_type: process.env.RESEND_BODY_TEMPLATE_TYPE,
         *      template_path: process.env.RESEND_TEMPLATE_PATH,
         *      order_placed_template: 'order_placed',
         *		 order_shipped_template: 'order_shipped',
         *		 customer_password_reset_template: 'customer_password_reset',
         *		 gift_card_created_template: 'gift_card_created',
         *		 order_canceled_template: 'order_canceled',
         *		 order_refund_created_template: 'order_refund_created',
         *		 order_return_requested_template: 'order_return_requested',
         *		 order_items_returned_template: 'order_items_returned',
         *		 swap_created_template: 'swap_created',
         *		 swap_shipment_created_template: 'swap_shipment_created',
         *		 swap_received_template: 'swap_received',
         *		 claim_shipment_created_template: 'claim_shipment_created',
         *		 user_password_reset_template: 'user_password_reset',
         *		 medusa_restock_template: 'medusa_restock',
         *    }
         */
        refundable?: number | null | undefined;
        subtotal?: number | null | undefined;
        tax_total?: number | null | undefined;
        total?: number | null | undefined;
        original_total?: number | null | undefined;
        original_tax_total?: number | null | undefined;
        discount_total?: number | null | undefined;
        raw_discount_total?: number | null | undefined;
        gift_card_total?: number | null | undefined;
        id: string;
        created_at: Date;
        updated_at: Date;
    }[];
    humanPrice_(amount: number | null | undefined, currency: string): string;
    normalizeThumbUrl_(url?: string | null): string | null;
    extractLocale(fromOrder: Order): Promise<{} | null>;
}
export default ResendService;
